@@ -156,6 +156,9 @@ class Gantt:
 
         # Create all the tasks
         for row in tasks:
+            #TODO: Error out if not unique id
+
+
             # Add new resources as encountered
             task_resources = []
             for r in row['resources']:
@@ -208,9 +211,11 @@ class Gantt:
                 )
 
         # set all the dependencies on created items from the created dependency map
-        for id, dependency_ids in dependency_map.items():
-            activities[id].dependencies = [activities[dependency_id] for dependency_id in dependency_ids
-                                           if dependency_id in activities.keys()]
+        for id, dependency in dependency_map.items():
+             dep_dict = {activities[dependency_id]: completion_threshold
+                           for dependency_id, completion_threshold in dependency.items()
+                           if dependency_id in activities.keys()}
+             activities[id].dependencies = dep_dict
 
         # add the resources to the gannt from the resource dict
         for r in resources_dict:
@@ -244,8 +249,9 @@ class Gantt:
             project = row['project']
 
             # Add new dependencies as encountered
-            row_dependency_list = row['dependencies'].split('&&') if row['dependencies'] != '' else []
-            row_dependency_list = [int(id) for id in row_dependency_list]
+            # row_dependency_list = row['dependencies'].split('&&') if row['dependencies'] != '' else []
+            row_dependency_list = eval(row['dependencies']) if row['dependencies'] != '' else {}
+            row_dependency_list = {int(id): completion_thresh for id, completion_thresh in row_dependency_list.items()}
 
             # sub activities
             # TODO: Add validation around the structure of sub activities
@@ -322,6 +328,18 @@ class Gantt:
         else:
             return False
 
+    def date_plus_working_days(self, start_date: date, days: int):
+        epoch = start_date
+        ii = 0
+        while ii < days:
+            epoch += ONE_DAY
+
+            if not self.date_skipped(epoch):
+              ii += 1
+
+
+        return epoch
+
     @property
     def non_weekend_skipped_days(self):
         return self._non_weekend_skipped_days
@@ -555,7 +573,7 @@ class Gantt:
         df['expected_duration_remaining'] = [(100 - task.percent_done) * task.duration / 100.0 for task in self.tasks]
         df['resources'] = ['&&'.join([resource.name for resource in task.resources]) for task in self.tasks]
         df['perc_done'] = [task.percent_done for task in self.tasks]
-        df['dependencies'] = ['&&'.join([dependency.id for dependency in task.dependencies]) for task in self.tasks]
+        df['dependencies'] = ['&&'.join([str(dependency.id) for dependency in task.dependencies]) for task in self.tasks]
         df['priority'] = [task.priority for task in self.tasks]
         df['scheduled_start_date'] = [task._start_date for task in self.tasks]
         df['scheduled_end_date'] = [task.end_date for task in self.tasks]
@@ -666,7 +684,7 @@ class ScheduledActivity(ABC):
                  target_completion_date: date = None,
                  closed_date: date = None,
                  resources:List[Resource]=None,
-                 dependencies=None,
+                 dependencies: Dict = None,
                  project:Project=None,
                  perc_done:int=0,
                  duration:int=None,
@@ -683,7 +701,7 @@ class ScheduledActivity(ABC):
             resources = []
 
         if dependencies is None:
-            dependencies = []
+            dependencies = {}
 
         self.resources = []
         for r in resources:
@@ -698,7 +716,7 @@ class ScheduledActivity(ABC):
 
         self.project = None
         self.set_project(project)
-        self._dependencies = None
+        self._dependencies = dependencies
         self._successors = []
         self.duration = duration
         self.priority = priority
@@ -715,7 +733,7 @@ class ScheduledActivity(ABC):
         return self._dependencies
 
     @dependencies.setter
-    def dependencies(self, dependants: List):
+    def dependencies(self, dependants: Dict):
         self._dependencies = dependants
         for obj in dependants:
             obj.add_successors([obj])
@@ -825,13 +843,17 @@ class ScheduledActivity(ABC):
         #   activity. There is opportunity to cache some information into a comparison matrix for quick lookups
 
         # Dependencies
-        for activity in self.dependencies:
+        for activity, completion_req in self.dependencies.items():
             if not activity.is_scheduled:
                 activity.schedule(start_date, max_resources_by_type_for_project)
 
             '''Update so self wont schedule until after the end of the dependency'''
-            if activity.end_date >= start_date:
-                schedule_start_date = max(activity.end_date + ONE_DAY, schedule_start_date)
+            dep_completion_thresh_days = round(activity.duration * completion_req, 0)
+            dep_completion_thresh_date = self.project.chart.date_plus_working_days(activity.start_date, dep_completion_thresh_days - 1)
+            schedule_start_date = max(dep_completion_thresh_date, schedule_start_date)
+
+            # if activity.end_date >= start_date:
+            #     schedule_start_date = max(activity.end_date + ONE_DAY, schedule_start_date)
 
         # Calculated Start Based on Completion
         if self.percent_done >0 and self.percent_done < 100:
@@ -868,20 +890,6 @@ class ScheduledActivity(ABC):
         return self.closed_date if self.closed_date else self.end_date_estimated
 
 
-
-        #
-        # work_done = 0
-        # end_date = self.start_date
-        #
-        # while work_done + 1 < self.duration and \
-        #         (end_date < self.closed_date if self.closed_date else True):
-        #     end_date += ONE_DAY
-        #
-        #     if not self.project.chart.date_skipped(end_date):
-        #     # if end_date.weekday() not in self.project.chart.weekend_days:
-        #         work_done += 1
-        # return end_date
-
     @property
     def end_date_estimated(self):
         """"""
@@ -898,7 +906,7 @@ class ScheduledActivity(ABC):
         work_done = 0
         end_date = self.start_date
 
-        work_to_do = (1 - self.percent_done/100.0) * self.duration
+        work_to_do = (1 - self.percent_done/100.0) * self.duration - 1
 
         # Need to cover the following cases:
         #   a. Scheduling in the past, there is still work that hasnt been scheduled
@@ -1056,7 +1064,7 @@ class Task(ScheduledActivity):
             len(self.dependencies),
             self.duration,
             self.start_date,
-            self.end_date,
+            self.closed_date,
             self.percent_done
         )
 
@@ -1120,4 +1128,10 @@ class SchedulingError(Exception):
     """
     pass
 
+if __name__ == "__main__":
+    date = date(month=5, year=2021, day=18)
+    gantt = Gantt("Name")
 
+    print(date)
+
+    print(gantt.date_plus_working_days(start_date=date, days=5 - 1))
