@@ -1,5 +1,5 @@
 from coopgantt.gantt import Gantt
-from datetime import timedelta
+from datetime import timedelta, datetime
 from typing import List
 import pkg_resources
 
@@ -75,13 +75,13 @@ def create_html(gantt: Gantt, svg_input_dir:str, embed_css: bool= True) -> str:
         <html lang="en">
         <head>
             <meta charset="UTF-8">
-            <title>Maestro Project Gantt</title>
+            <title>{gantt.name}</title>
             <style>{css_data}</style>
         </head>
         <body>
             
             <div class="header">
-                    <H1>Maestro Project Gantt</H1>
+                    <H1>{gantt.name}</H1><small>Generated at: {datetime.now().strftime("%Y-%m-%d %H:%M")}</small>
                     <div class="windowed_view" id="windowed_view">
                         {svg_header_data}
                     </div>
