@@ -562,21 +562,23 @@ def svg_of_task(task: Task, prev_y=0, start=None, end=None, color=None, level=No
     background.attribs['class'] = 'task'
     svg.add(background)
 
-    # Missed Target Mark
-    if add_target_end_mark and task.target_completion_date and task.target_completion_date < task.end_date:
+    # Target Mark
+    if add_target_end_mark and task.target_completion_date:
+        target_color = "#00a2ff" if task.target_completion_date > task.end_date else "#ff0000"
+
         beg_offset = _time_diff(task.target_completion_date, start) * 10
         svg.add(svgwrite.shapes.Rect(
                 insert=((beg_offset+1)*mm, (y+1)*mm),
                 size=(5*mm, 8*mm),
-                fill="#ff0000",
-                stroke="#ff0000",
+                fill=target_color,
+                stroke=target_color,
                 stroke_width=1,
                 opacity=0.35,
                 ))
         svg.add(svgwrite.shapes.Rect(
             insert=((x + 1 + offset) * mm, (y + 1) * mm),
             size=((d - 2) * mm, 8 * mm),
-            stroke="#ff0000",
+            stroke=target_color,
             stroke_width=2,
             fill_opacity=0.0,
             class_='task',
